@@ -81,6 +81,13 @@ class PolishPreProcessor():
                     'pacta' : 'VERB',
                     'numcomp' : 'NUM'}
 
+  def reload_dict(self, dict_name, dict_path):
+    # A method for loading custom Morfeusz dictionaries
+    self.morf = morfeusz2.Morfeusz(generate = False,
+                                   whitespace = morfeusz2.KEEP_WHITESPACES,
+                                   expand_tags=True,
+                                   dict_name=dict_name, dict_path=dict_path)
+
 
   def disambiguate_tokenization(self, analyses):
     # The logic of this function is a bit messy and could be improved
@@ -199,7 +206,6 @@ class PolishPreProcessor():
       return empty_doc
     position_to_analyses = self.disambiguate_tokenization(analyses)
     
-    #non_white_analysis, words, space_afters = self.skip_white_space(position_to_analyses)
     non_white_analysis, words, space_afters = self.skip_white_space_list(position_to_analyses)
 
     # Saving the tokenization
